==> hlint-2.0.9-22-i686.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.0.9
id: hlint-2.0.9-CUlbTLdbK6mLbWvzkgNU23
key: hlint-2.0.9-CUlbTLdbK6mLbWvzkgNU23
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Config.All Config.Compute
                Config.Haskell Config.Type Config.Yaml HSE.All HSE.Bracket
                HSE.FreeVars HSE.Match HSE.Reduce HSE.Scope HSE.Type HSE.Util
                Hint.All Hint.Bracket Hint.Comment Hint.Duplicate Hint.Export
                Hint.Extensions Hint.Import Hint.Lambda Hint.List Hint.ListRec
                Hint.Match Hint.Monad Hint.Naming Hint.NewType Hint.Pattern
                Hint.Pragma Hint.Restrict Hint.Type Hint.Unsafe Hint.Util Test.All
                Test.Annotations Test.InputOutput Test.Proof Test.Translate
                Test.Util
abi: ebc15cca135dc26715bee676a7398123
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hlint-2.0.9
library-dirs: /usr/lib/ghc-8.2.1/site-local/hlint-2.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.0.9-CUlbTLdbK6mLbWvzkgNU23
depends:
    base-4.10.0.0 process-1.6.1.0 filepath-1.4.1.2 directory-1.3.0.2
    containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    yaml-0.8.23.3-AZSsApCdj2T3XfDE7MlqSi
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    transformers-0.5.2.0 cpphs-1.20.8-7xqV6K11ztn3NWgQm6oXk8
    cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf
    haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR
    uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
    extra-1.6-21C3t0YQFbADxH75E4GqjW
    refact-0.3.0.2-EEksmjDjDC24IXx8jwL0uo
    hscolour-1.24.1-8VIByEGMUB98gZuOLuHUQk
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             yaml-0.8.23.3-AZSsApCdj2T3XfDE7MlqSi=7a6af61a5a6f451ce0540a63a6a62d32
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             cpphs-1.20.8-7xqV6K11ztn3NWgQm6oXk8=581e02bd68f6154a4dac378fca4280fb
             cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf=7dc5ecfdbaee81800275945c72ee928b
             haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR=ac9b27fa2ca0fe7a0941d00fbc5a411d
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             extra-1.6-21C3t0YQFbADxH75E4GqjW=90b9a896fb2ef8ae52715c35e2c32c8c
             refact-0.3.0.2-EEksmjDjDC24IXx8jwL0uo=7fa30bc8296cd156035027f73138a32c
             hscolour-1.24.1-8VIByEGMUB98gZuOLuHUQk=b34023c8fce14783cced9942c4c3a0b5
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-2.0.9-23-i686.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.0.9
id: hlint-2.0.9-Fedluv50LyWHJo64IdMc2Q
key: hlint-2.0.9-Fedluv50LyWHJo64IdMc2Q
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Config.All Config.Compute
                Config.Haskell Config.Type Config.Yaml HSE.All HSE.Bracket
                HSE.FreeVars HSE.Match HSE.Reduce HSE.Scope HSE.Type HSE.Util
                Hint.All Hint.Bracket Hint.Comment Hint.Duplicate Hint.Export
                Hint.Extensions Hint.Import Hint.Lambda Hint.List Hint.ListRec
                Hint.Match Hint.Monad Hint.Naming Hint.NewType Hint.Pattern
                Hint.Pragma Hint.Restrict Hint.Type Hint.Unsafe Hint.Util Test.All
                Test.Annotations Test.InputOutput Test.Proof Test.Translate
                Test.Util
abi: 56f98fdc506602658d31d806ae3fa4e2
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hlint-2.0.9
library-dirs: /usr/lib/ghc-8.2.1/site-local/hlint-2.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.0.9-Fedluv50LyWHJo64IdMc2Q
depends:
    base-4.10.0.0 process-1.6.1.0 filepath-1.4.1.2 directory-1.3.0.2
    containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    yaml-0.8.23.3-2QGOHBHHpaurEGLPcLVJG
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    transformers-0.5.2.0 cpphs-1.20.8-7xqV6K11ztn3NWgQm6oXk8
    cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf
    haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR
    uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
    extra-1.6-21C3t0YQFbADxH75E4GqjW
    refact-0.3.0.2-EEksmjDjDC24IXx8jwL0uo
    hscolour-1.24.1-8VIByEGMUB98gZuOLuHUQk
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             yaml-0.8.23.3-2QGOHBHHpaurEGLPcLVJG=2c546b36221194a2b134d5137464910f
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             cpphs-1.20.8-7xqV6K11ztn3NWgQm6oXk8=581e02bd68f6154a4dac378fca4280fb
             cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf=7dc5ecfdbaee81800275945c72ee928b
             haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR=ac9b27fa2ca0fe7a0941d00fbc5a411d
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             extra-1.6-21C3t0YQFbADxH75E4GqjW=90b9a896fb2ef8ae52715c35e2c32c8c
             refact-0.3.0.2-EEksmjDjDC24IXx8jwL0uo=7fa30bc8296cd156035027f73138a32c
             hscolour-1.24.1-8VIByEGMUB98gZuOLuHUQk=b34023c8fce14783cced9942c4c3a0b5
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
